universal_asset library

Universal Asset Package

A lightweight, modular Flutter package for displaying different types of assets (images, SVGs, Lottie animations, Rive animations) using a single widget.

Classes

AssetTypeDetector
Utility class for detecting asset types
LottieConfig
Configuration class for Lottie animations
NetworkImageConfig
Configuration class for network images
RiveConfig
Configuration class for Rive animations
SvgConfig
Configuration class for SVG rendering
UniversalAsset
A universal widget for displaying different types of assets

Enums

AssetType
Enumeration of supported asset types